    	SUBROUTINE IFTEXT( NCHS, TEXT, IR, ARRAY )
C
C  PROGRAMMER:  R.S. ZHOU
C		ALFRED UNIVERSITY	JAN-1986
C
C	THIS ROUTINE HANDLES THE GRAPHTEXT PLOTTING.
C
C	NCHS -------- NUMBER OF CHARACTERS IN "TEXT".
C	TEXT -------- TEXTSTRING TO BE PLOTTED IN CHARACTER FORMAT.
C	IR ---------- LENGTH OF THE "ARRAY"
C	ARRAY(1) ---- STARTING POSITION (X) OF "TEXT".
C	ARRAY(2) ---- STARTING POSITION (Y) OF "TEXT"
C	ARRAY(3) ---- WIDTH OF "TEXT" IN INCHES.
C	ARRAY(4) ---- HEIGHT OF "TEXT" IN INCHES.
C	ARRAY(5) ---- ROTATION ANGLE OF "TEXT" IN DEGREES.
C
    	INCLUDE 'IMAGEM.CBS'
    	CHARACTER	TEXT(1)*1
     	DIMENSION	ARRAY(1)

	IF( NCHS.EQ.0 .OR. ANGLE.NE.0.0 ) RETURN
     	NCH = IABS(NCHS)
C
C  MOVE TO THE STARTING POSITION...
C
    	IF( IR.GT.1 ) CALL IFDRAW( ARRAY(1), ARRAY(2), 3 )
C
C  LOAD THE LABEL...
C
     	IF( IPL.GT.NBS-NCH-3 ) CALL IFINIT_DUMP
     	IPB(IPL+1) = 'L'
     	IPB(IPL+2) = 'B'
    	IPL = IPL + 2
    	DO I=1, NCH
    	    IPL = IPL + 1
    	    IPB(IPL) = ICHAR(TEXT(I))
    	ENDDO
    	IPL = IPL + 1
    	IPB(IPL) = 3

999	RETURN
    	END

